Class: Google::Cloud::Run::V2::ContainerStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/container_status.rb

Overview

ContainerStatus holds the information of container name and image digest value.

Instance Attribute Summary collapse

Instance Attribute Details

#image_digest::String

Returns ImageDigest holds the resolved digest for the image specified and resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object.

Returns:

  • (::String)

    ImageDigest holds the resolved digest for the image specified and resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object.



35
36
37
38
# File 'proto_docs/google/cloud/run/v2/container_status.rb', line 35

class ContainerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The name of the container, if specified.

Returns:

  • (::String)

    The name of the container, if specified.



35
36
37
38
# File 'proto_docs/google/cloud/run/v2/container_status.rb', line 35

class ContainerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end