Class: Google::Cloud::Run::V2::CreateInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/instance.rb

Instance Attribute Summary collapse

Instance Attribute Details

#instance::Google::Cloud::Run::V2::Instance



37
38
39
40
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 37

class CreateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_id::String

Returns Required. The unique identifier for the Instance. It must begin with letter, and cannot end with hyphen; must contain fewer than 50 characters. The name of the instance becomes {parent}/instances/{instance_id}.

Returns:

  • (::String)

    Required. The unique identifier for the Instance. It must begin with letter, and cannot end with hyphen; must contain fewer than 50 characters. The name of the instance becomes {parent}/instances/{instance_id}.



37
38
39
40
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 37

class CreateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns:

  • (::String)


37
38
39
40
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 37

class CreateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. Indicates that the request should be validated and default values populated, without persisting the request or creating any resources.

Returns:

  • (::Boolean)

    Optional. Indicates that the request should be validated and default values populated, without persisting the request or creating any resources.



37
38
39
40
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 37

class CreateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end