Class: Google::Cloud::Run::V2::DeleteInstanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::DeleteInstanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/instance.rb
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
- #name ⇒ ::String
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates.
59 60 61 62 |
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 59 class DeleteInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
59 60 61 62 |
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 59 class DeleteInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. Indicates that the request should be validated without actually deleting any resources.
59 60 61 62 |
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 59 class DeleteInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |