Class: Google::Cloud::Run::V2::ListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/instance.rb

Overview

Request message for retrieving a list of Instances.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Maximum number of Instances to return in this call.

Returns:

  • (::Integer)

    Optional. Maximum number of Instances to return in this call.



81
82
83
84
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 81

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token received from a previous call to ListInstances. All other parameters must match.

Returns:

  • (::String)

    Optional. A page token received from a previous call to ListInstances. All other parameters must match.



81
82
83
84
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 81

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The location and project to list resources on. Format: projects/{project}/locations/{location}, where {project} can be project id or number.

Returns:

  • (::String)

    Required. The location and project to list resources on. Format: projects/{project}/locations/{location}, where {project} can be project id or number.



81
82
83
84
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 81

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#show_deleted::Boolean

Returns Optional. If true, returns deleted (but unexpired) resources along with active ones.

Returns:

  • (::Boolean)

    Optional. If true, returns deleted (but unexpired) resources along with active ones.



81
82
83
84
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 81

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end