Class: Google::Cloud::Run::V2::ListInstancesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/instance.rb

Overview

Response message containing a list of Instances.

Instance Attribute Summary collapse

Instance Attribute Details

#instances::Array<::Google::Cloud::Run::V2::Instance>

Returns The resulting list of Instances.

Returns:



94
95
96
97
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 94

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token indicating there are more items than page_size. Use it in the next ListInstances request to continue.

Returns:

  • (::String)

    A token indicating there are more items than page_size. Use it in the next ListInstances request to continue.



94
95
96
97
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 94

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end