Class: Google::Cloud::Run::V2::ListServicesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::ListServicesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/service.rb
Overview
Response message containing a list of Services.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token indicating there are more items than page_size.
-
#services ⇒ ::Array<::Google::Cloud::Run::V2::Service>
The resulting list of Services.
-
#unreachable ⇒ ::Array<::String>
readonly
Output only.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token indicating there are more items than page_size. Use it in the next ListServices request to continue.
102 103 104 105 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 102 class ListServicesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#services ⇒ ::Array<::Google::Cloud::Run::V2::Service>
Returns The resulting list of Services.
102 103 104 105 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 102 class ListServicesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String> (readonly)
Returns Output only. For global requests, returns the list of regions that could not be reached within the deadline.
102 103 104 105 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 102 class ListServicesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |