Class: Google::Cloud::Run::V2::NFSVolumeSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/k8s.min.rb

Overview

Represents an NFS mount.

Instance Attribute Summary collapse

Instance Attribute Details

#path ⇒ ::String

Returns Path that is exported by the NFS server.

Returns:

  • (::String) —

    Path that is exported by the NFS server.



383
384
385
386
# File 'proto_docs/google/cloud/run/v2/k8s.min.rb', line 383

class NFSVolumeSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#read_only ⇒ ::Boolean

Returns If true, the volume will be mounted as read only for all mounts.

Returns:

  • (::Boolean) —

    If true, the volume will be mounted as read only for all mounts.



383
384
385
386
# File 'proto_docs/google/cloud/run/v2/k8s.min.rb', line 383

class NFSVolumeSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#server ⇒ ::String

Returns Hostname or IP address of the NFS server.

Returns:

  • (::String) —

    Hostname or IP address of the NFS server



383
384
385
386
# File 'proto_docs/google/cloud/run/v2/k8s.min.rb', line 383

class NFSVolumeSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end