Class: Google::Cloud::Run::V2::ResourceRequirements

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/k8s.min.rb

Overview

ResourceRequirements describes the compute resource requirements.

Defined Under Namespace

Classes: LimitsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_idle::Boolean

Returns Determines whether CPU is only allocated during requests (true by default). However, if ResourceRequirements is set, the caller must explicitly set this field to true to preserve the default behavior.

Returns:

  • (::Boolean)

    Determines whether CPU is only allocated during requests (true by default). However, if ResourceRequirements is set, the caller must explicitly set this field to true to preserve the default behavior.



120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/run/v2/k8s.min.rb', line 120

class ResourceRequirements
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LimitsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#limits::Google::Protobuf::Map{::String => ::String}

Returns Only memory, cpu and nvidia.com/gpu keys in the map are supported.

Notes:

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/run/v2/k8s.min.rb', line 120

class ResourceRequirements
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LimitsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#startup_cpu_boost::Boolean

Returns Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.

Returns:

  • (::Boolean)

    Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.



120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/run/v2/k8s.min.rb', line 120

class ResourceRequirements
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LimitsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end