Class: Google::Cloud::Run::V2::RevisionScaling
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::RevisionScaling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/vendor_settings.rb
Overview
Settings for revision-level scaling settings.
Instance Attribute Summary collapse
-
#max_instance_count ⇒ ::Integer
Optional.
-
#min_instance_count ⇒ ::Integer
Optional.
Instance Attribute Details
#max_instance_count ⇒ ::Integer
Returns Optional. Maximum number of serving instances that this resource should have. When unspecified, the field is set to the server default value of 100. For more information see https://cloud.google.com/run/docs/configuring/max-instances.
116 117 118 119 |
# File 'proto_docs/google/cloud/run/v2/vendor_settings.rb', line 116 class RevisionScaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_instance_count ⇒ ::Integer
Returns Optional. Minimum number of serving instances that this resource should have.
116 117 118 119 |
# File 'proto_docs/google/cloud/run/v2/vendor_settings.rb', line 116 class RevisionScaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |