Class: Google::Cloud::Run::V2::Service
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::Service
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/service.rb
Overview
Service acts as a top-level container that manages a set of configurations and revision templates which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership.
Defined Under Namespace
Classes: AnnotationsEntry, LabelsEntry, MultiRegionSettings
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#binary_authorization ⇒ ::Google::Cloud::Run::V2::BinaryAuthorization
Optional.
-
#build_config ⇒ ::Google::Cloud::Run::V2::BuildConfig
Optional.
-
#client ⇒ ::String
Arbitrary identifier for the API client.
-
#client_version ⇒ ::String
Arbitrary version identifier for the API client.
-
#conditions ⇒ ::Array<::Google::Cloud::Run::V2::Condition>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#creator ⇒ ::String
readonly
Output only.
-
#custom_audiences ⇒ ::Array<::String>
One or more custom audiences that you want this service to support.
-
#default_uri_disabled ⇒ ::Boolean
Optional.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
User-provided description of the Service.
-
#etag ⇒ ::String
Optional.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#generation ⇒ ::Integer
readonly
Output only.
-
#iap_enabled ⇒ ::Boolean
Optional.
-
#ingress ⇒ ::Google::Cloud::Run::V2::IngressTraffic
Optional.
-
#invoker_iam_disabled ⇒ ::Boolean
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#last_modifier ⇒ ::String
readonly
Output only.
-
#latest_created_revision ⇒ ::String
readonly
Output only.
-
#latest_ready_revision ⇒ ::String
readonly
Output only.
-
#launch_stage ⇒ ::Google::Api::LaunchStage
Optional.
-
#multi_region_settings ⇒ ::Google::Cloud::Run::V2::Service::MultiRegionSettings
Optional.
-
#name ⇒ ::String
Identifier.
-
#observed_generation ⇒ ::Integer
readonly
Output only.
-
#reconciling ⇒ ::Boolean
readonly
Output only.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#scaling ⇒ ::Google::Cloud::Run::V2::ServiceScaling
Optional.
-
#template ⇒ ::Google::Cloud::Run::V2::RevisionTemplate
Required.
-
#terminal_condition ⇒ ::Google::Cloud::Run::V2::Condition
readonly
Output only.
-
#threat_detection_enabled ⇒ ::Boolean
readonly
Output only.
-
#traffic ⇒ ::Array<::Google::Cloud::Run::V2::TrafficTarget>
Optional.
-
#traffic_statuses ⇒ ::Array<::Google::Cloud::Run::V2::TrafficTargetStatus>
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#uri ⇒ ::String
readonly
Output only.
-
#urls ⇒ ::Array<::String>
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects.
Cloud Run API v2 does not support annotations with run.googleapis.com,
cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev
namespaces, and they will be rejected in new resources. All system
annotations in v1 now have a corresponding field in v2 Service.
This field follows Kubernetes annotations' namespacing, limits, and rules.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#binary_authorization ⇒ ::Google::Cloud::Run::V2::BinaryAuthorization
Returns Optional. Settings for the Binary Authorization feature.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#build_config ⇒ ::Google::Cloud::Run::V2::BuildConfig
Returns Optional. Configuration for building a Cloud Run function.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#client ⇒ ::String
Returns Arbitrary identifier for the API client.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#client_version ⇒ ::String
Returns Arbitrary version identifier for the API client.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#conditions ⇒ ::Array<::Google::Cloud::Run::V2::Condition> (readonly)
Returns Output only. The Conditions of all other associated sub-resources. They
contain additional diagnostics information in case the Service does not
reach its Serving state. See comments in reconciling for additional
information on reconciliation process in Cloud Run.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation time.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#creator ⇒ ::String (readonly)
Returns Output only. Email address of the authenticated creator.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_audiences ⇒ ::Array<::String>
Returns One or more custom audiences that you want this service to support. Specify each custom audience as the full URL in a string. The custom audiences are encoded in the token and used to authenticate requests. For more information, see https://cloud.google.com/run/docs/configuring/custom-audiences.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_uri_disabled ⇒ ::Boolean
Returns Optional. Disables public resolution of the default URI of this service.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The deletion time. It is only populated as a response to a Delete request.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns User-provided description of the Service. This field currently has a 512-character limit.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String
Returns Optional. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#expire_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. For a deleted resource, the time after which it will be permanently deleted.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#generation ⇒ ::Integer (readonly)
Returns Output only. A number that monotonically increases every time the user
modifies the desired state.
Please note that unlike v1, this is an int64 value. As with most Google
APIs, its JSON representation will be a string instead of an integer.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#iap_enabled ⇒ ::Boolean
Returns Optional. IAP settings on the Service.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ingress ⇒ ::Google::Cloud::Run::V2::IngressTraffic
Optional. Provides the ingress settings for this Service. On output, returns the currently observed ingress settings, or INGRESS_TRAFFIC_UNSPECIFIED if no revision is active.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#invoker_iam_disabled ⇒ ::Boolean
Returns Optional. Disables IAM permission check for run.routes.invoke for callers of this service. For more information, visit https://cloud.google.com/run/docs/securing/managing-access#invoker_check.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud.google.com/resource-manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/configuring/labels.
Cloud Run API v2 does not support labels with run.googleapis.com,
cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev
namespaces, and they will be rejected. All system labels in v1 now have a
corresponding field in v2 Service.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#last_modifier ⇒ ::String (readonly)
Returns Output only. Email address of the last authenticated modifier.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#latest_created_revision ⇒ ::String (readonly)
Returns Output only. Name of the last created revision. See comments in
reconciling for additional information on reconciliation process in Cloud
Run.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#latest_ready_revision ⇒ ::String (readonly)
Returns Output only. Name of the latest revision that is serving traffic. See
comments in reconciling for additional information on reconciliation
process in Cloud Run.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#launch_stage ⇒ ::Google::Api::LaunchStage
Returns Optional. The launch stage as defined by Google Cloud Platform
Launch Stages.
Cloud Run supports ALPHA, BETA, and GA. If no value is specified, GA
is assumed.
Set the launch stage to a preview stage on input to allow use of preview
features in that stage. On read (or output), describes whether the resource
uses preview features.
For example, if ALPHA is provided as input, but only BETA and GA-level features are used, this field will be BETA on output.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multi_region_settings ⇒ ::Google::Cloud::Run::V2::Service::MultiRegionSettings
Returns Optional. Settings for multi-region deployment.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The fully qualified name of this Service. In CreateServiceRequest, this field is ignored, and instead composed from CreateServiceRequest.parent and CreateServiceRequest.service_id.
Format: projects/{project}/locations/{location}/services/{service_id}.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#observed_generation ⇒ ::Integer (readonly)
Returns Output only. The generation of this Service currently serving traffic. See
comments in reconciling for additional information on reconciliation
process in Cloud Run. Please note that unlike v1, this is an int64 value.
As with most Google APIs, its JSON representation will be a string
instead of an integer.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#reconciling ⇒ ::Boolean (readonly)
Returns Output only. Returns true if the Service is currently being acted upon by the system to bring it into the desired state.
When a new Service is created, or an existing one is updated, Cloud Run
will asynchronously perform all necessary steps to bring the Service to the
desired serving state. This process is called reconciliation.
While reconciliation is in process, observed_generation,
latest_ready_revision, traffic_statuses, and uri will have transient
values that might mismatch the intended state: Once reconciliation is over
(and this field is false), there are two possible outcomes: reconciliation
succeeded and the serving state matches the Service, or there was an error,
and reconciliation failed. This state can be found in
terminal_condition.state.
If reconciliation succeeded, the following fields will match: traffic and
traffic_statuses, observed_generation and generation,
latest_ready_revision and latest_created_revision.
If reconciliation failed, traffic_statuses, observed_generation, and
latest_ready_revision will have the state of the last serving revision,
or empty for newly created Services. Additional information on the failure
can be found in terminal_condition and conditions.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scaling ⇒ ::Google::Cloud::Run::V2::ServiceScaling
Returns Optional. Specifies service-level scaling settings.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#template ⇒ ::Google::Cloud::Run::V2::RevisionTemplate
Returns Required. The template used to create revisions for this Service.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#terminal_condition ⇒ ::Google::Cloud::Run::V2::Condition (readonly)
Returns Output only. The Condition of this Service, containing its readiness
status, and detailed error information in case it did not reach a serving
state. See comments in reconciling for additional information on
reconciliation process in Cloud Run.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#threat_detection_enabled ⇒ ::Boolean (readonly)
Returns Output only. True if Cloud Run Threat Detection monitoring is enabled for the parent project of this Service.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#traffic ⇒ ::Array<::Google::Cloud::Run::V2::TrafficTarget>
Returns Optional. Specifies how to distribute traffic over a collection of
Revisions belonging to the Service. If traffic is empty or not provided,
defaults to 100% traffic to the latest Ready Revision.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#traffic_statuses ⇒ ::Array<::Google::Cloud::Run::V2::TrafficTargetStatus> (readonly)
Returns Output only. Detailed status information for corresponding traffic targets.
See comments in reconciling for additional information on reconciliation
process in Cloud Run.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. Server assigned unique identifier for the trigger. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last-modified time.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uri ⇒ ::String (readonly)
Returns Output only. The main URI in which this Service is serving traffic.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#urls ⇒ ::Array<::String> (readonly)
Returns Output only. All URLs serving traffic for this Service.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'proto_docs/google/cloud/run/v2/service.rb', line 347 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for multi-region deployment. # @!attribute [rw] regions # @return [::Array<::String>] # Required. List of regions to deploy to, including primary region. # @!attribute [rw] multi_region_id # @return [::String] # Optional. System-generated unique id for the multi-region Service. class MultiRegionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |