Class: Google::Cloud::Run::V2::ServiceScaling
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::ServiceScaling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/vendor_settings.rb
Overview
Scaling settings applied at the service level rather than at the revision level.
Defined Under Namespace
Modules: ScalingMode
Instance Attribute Summary collapse
-
#manual_instance_count ⇒ ::Integer
Optional.
-
#max_instance_count ⇒ ::Integer
Optional.
-
#min_instance_count ⇒ ::Integer
Optional.
-
#scaling_mode ⇒ ::Google::Cloud::Run::V2::ServiceScaling::ScalingMode
Optional.
Instance Attribute Details
#manual_instance_count ⇒ ::Integer
Returns Optional. total instance count for the service in manual scaling mode. This number of instances is divided among all revisions with specified traffic based on the percent of traffic they are receiving.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'proto_docs/google/cloud/run/v2/vendor_settings.rb', line 153 class ServiceScaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scaling mode for the service. If not provided, it defaults to # AUTOMATIC. module ScalingMode # Unspecified. SCALING_MODE_UNSPECIFIED = 0 # Scale based on traffic between min and max instances. AUTOMATIC = 1 # Scale to exactly min instances and ignore max instances. MANUAL = 2 end end |
#max_instance_count ⇒ ::Integer
Returns Optional. total max instances for the service. This number of instances is divided among all revisions with specified traffic based on the percent of traffic they are receiving.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'proto_docs/google/cloud/run/v2/vendor_settings.rb', line 153 class ServiceScaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scaling mode for the service. If not provided, it defaults to # AUTOMATIC. module ScalingMode # Unspecified. SCALING_MODE_UNSPECIFIED = 0 # Scale based on traffic between min and max instances. AUTOMATIC = 1 # Scale to exactly min instances and ignore max instances. MANUAL = 2 end end |
#min_instance_count ⇒ ::Integer
Returns Optional. total min instances for the service. This number of instances is divided among all revisions with specified traffic based on the percent of traffic they are receiving.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'proto_docs/google/cloud/run/v2/vendor_settings.rb', line 153 class ServiceScaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scaling mode for the service. If not provided, it defaults to # AUTOMATIC. module ScalingMode # Unspecified. SCALING_MODE_UNSPECIFIED = 0 # Scale based on traffic between min and max instances. AUTOMATIC = 1 # Scale to exactly min instances and ignore max instances. MANUAL = 2 end end |
#scaling_mode ⇒ ::Google::Cloud::Run::V2::ServiceScaling::ScalingMode
Returns Optional. The scaling mode for the service.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'proto_docs/google/cloud/run/v2/vendor_settings.rb', line 153 class ServiceScaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scaling mode for the service. If not provided, it defaults to # AUTOMATIC. module ScalingMode # Unspecified. SCALING_MODE_UNSPECIFIED = 0 # Scale based on traffic between min and max instances. AUTOMATIC = 1 # Scale to exactly min instances and ignore max instances. MANUAL = 2 end end |