Class: Google::Cloud::Run::V2::StopInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/instance.rb

Overview

Request message for deleting an Instance.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. A system-generated fingerprint for this version of the resource. This may be used to detect modification conflict during updates.

Returns:

  • (::String)

    Optional. A system-generated fingerprint for this version of the resource. This may be used to detect modification conflict during updates.



114
115
116
117
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 114

class StopInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the Instance to stop. Format: projects/{project}/locations/{location}/instances/{instance}, where {project} can be project id or number.

Returns:

  • (::String)

    Required. The name of the Instance to stop. Format: projects/{project}/locations/{location}/instances/{instance}, where {project} can be project id or number.



114
115
116
117
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 114

class StopInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. Indicates that the request should be validated without actually stopping any resources.

Returns:

  • (::Boolean)

    Optional. Indicates that the request should be validated without actually stopping any resources.



114
115
116
117
# File 'proto_docs/google/cloud/run/v2/instance.rb', line 114

class StopInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end