Class: Google::Cloud::Run::V2::SubmitBuildRequest::BuildpacksBuild

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/run/v2/build.rb

Overview

Build the source using Buildpacks.

Defined Under Namespace

Classes: EnvironmentVariablesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#base_image::String

Returns Optional. The base image to use for the build.

Returns:

  • (::String)

    Optional. The base image to use for the build.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#cache_image_uri::String

Returns Optional. cache_image_uri is the GCR/AR URL where the cache image will be stored. cache_image_uri is optional and omitting it will disable caching. This URL must be stable across builds. It is used to derive a build-specific temporary URL by substituting the tag with the build ID. The build will clean up the temporary image on a best-effort basis.

Returns:

  • (::String)

    Optional. cache_image_uri is the GCR/AR URL where the cache image will be stored. cache_image_uri is optional and omitting it will disable caching. This URL must be stable across builds. It is used to derive a build-specific temporary URL by substituting the tag with the build ID. The build will clean up the temporary image on a best-effort basis.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#enable_automatic_updates::Boolean

Returns Optional. Whether or not the application container will be enrolled in automatic base image updates. When true, the application will be built on a scratch base image, so the base layers can be appended at run time.

Returns:

  • (::Boolean)

    Optional. Whether or not the application container will be enrolled in automatic base image updates. When true, the application will be built on a scratch base image, so the base layers can be appended at run time.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#environment_variables::Google::Protobuf::Map{::String => ::String}

Returns Optional. User-provided build-time environment variables.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. User-provided build-time environment variables.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#function_target::String

Returns Optional. Name of the function target if the source is a function source. Required for function builds.

Returns:

  • (::String)

    Optional. Name of the function target if the source is a function source. Required for function builds.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#project_descriptor::String

Returns Optional. project_descriptor stores the path to the project descriptor file. When empty, it means that there is no project descriptor file in the source.

Returns:

  • (::String)

    Optional. project_descriptor stores the path to the project descriptor file. When empty, it means that there is no project descriptor file in the source.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#runtime::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns The runtime name, e.g. 'go113'. Leave blank for generic builds.

Returns:

  • (::String)

    The runtime name, e.g. 'go113'. Leave blank for generic builds.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'proto_docs/google/cloud/run/v2/build.rb', line 115

class BuildpacksBuild
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class EnvironmentVariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end