Class: Google::Cloud::Run::V2::TaskTemplate
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::TaskTemplate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/task_template.rb
Overview
TaskTemplate describes the data a task should have when created from a template.
Instance Attribute Summary collapse
-
#containers ⇒ ::Array<::Google::Cloud::Run::V2::Container>
Holds the single container that defines the unit of execution for this task.
-
#encryption_key ⇒ ::String
A reference to a customer managed encryption key (CMEK) to use to encrypt this container image.
-
#execution_environment ⇒ ::Google::Cloud::Run::V2::ExecutionEnvironment
Optional.
-
#max_retries ⇒ ::Integer
Number of retries allowed per Task, before marking this Task failed.
-
#service_account ⇒ ::String
Optional.
-
#timeout ⇒ ::Google::Protobuf::Duration
Optional.
-
#volumes ⇒ ::Array<::Google::Cloud::Run::V2::Volume>
Optional.
-
#vpc_access ⇒ ::Google::Cloud::Run::V2::VpcAccess
Optional.
Instance Attribute Details
#containers ⇒ ::Array<::Google::Cloud::Run::V2::Container>
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encryption_key ⇒ ::String
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#execution_environment ⇒ ::Google::Cloud::Run::V2::ExecutionEnvironment
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_retries ⇒ ::Integer
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_account ⇒ ::String
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timeout ⇒ ::Google::Protobuf::Duration
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#volumes ⇒ ::Array<::Google::Cloud::Run::V2::Volume>
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vpc_access ⇒ ::Google::Cloud::Run::V2::VpcAccess
62 63 64 65 |
# File 'proto_docs/google/cloud/run/v2/task_template.rb', line 62 class TaskTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |