Class: Google::Cloud::Run::V2::WorkerPool
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::WorkerPool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/worker_pool.rb
Overview
WorkerPool acts as a top-level container that manages a set of configurations and revision templates which implement a pull-based workload. WorkerPool exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership.
Defined Under Namespace
Classes: AnnotationsEntry, LabelsEntry
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#binary_authorization ⇒ ::Google::Cloud::Run::V2::BinaryAuthorization
Optional.
-
#client ⇒ ::String
Arbitrary identifier for the API client.
-
#client_version ⇒ ::String
Arbitrary version identifier for the API client.
-
#conditions ⇒ ::Array<::Google::Cloud::Run::V2::Condition>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#creator ⇒ ::String
readonly
Output only.
-
#custom_audiences ⇒ ::Array<::String>
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
User-provided description of the WorkerPool.
-
#etag ⇒ ::String
Optional.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#generation ⇒ ::Integer
readonly
Output only.
-
#instance_split_statuses ⇒ ::Array<::Google::Cloud::Run::V2::InstanceSplitStatus>
readonly
Output only.
-
#instance_splits ⇒ ::Array<::Google::Cloud::Run::V2::InstanceSplit>
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#last_modifier ⇒ ::String
readonly
Output only.
-
#latest_created_revision ⇒ ::String
readonly
Output only.
-
#latest_ready_revision ⇒ ::String
readonly
Output only.
-
#launch_stage ⇒ ::Google::Api::LaunchStage
Optional.
-
#name ⇒ ::String
The fully qualified name of this WorkerPool.
-
#observed_generation ⇒ ::Integer
readonly
Output only.
-
#reconciling ⇒ ::Boolean
readonly
Output only.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#scaling ⇒ ::Google::Cloud::Run::V2::WorkerPoolScaling
Optional.
-
#template ⇒ ::Google::Cloud::Run::V2::WorkerPoolRevisionTemplate
Required.
-
#terminal_condition ⇒ ::Google::Cloud::Run::V2::Condition
readonly
Output only.
-
#threat_detection_enabled ⇒ ::Boolean
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects.
Cloud Run API v2 does not support annotations with run.googleapis.com,
cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev
namespaces, and they will be rejected in new resources. All system
annotations in v1 now have a corresponding field in v2 WorkerPool.
This field follows Kubernetes annotations' namespacing, limits, and rules.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#binary_authorization ⇒ ::Google::Cloud::Run::V2::BinaryAuthorization
Returns Optional. Settings for the Binary Authorization feature.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#client ⇒ ::String
Returns Arbitrary identifier for the API client.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#client_version ⇒ ::String
Returns Arbitrary version identifier for the API client.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#conditions ⇒ ::Array<::Google::Cloud::Run::V2::Condition> (readonly)
Returns Output only. The Conditions of all other associated sub-resources. They
contain additional diagnostics information in case the WorkerPool does not
reach its Serving state. See comments in reconciling for additional
information on reconciliation process in Cloud Run.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation time.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#creator ⇒ ::String (readonly)
Returns Output only. Email address of the authenticated creator.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_audiences ⇒ ::Array<::String>
This field is deprecated and may be removed in the next major version update.
Returns Deprecated: Not supported, and ignored by Cloud Run.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The deletion time. It is only populated as a response to a Delete request.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns User-provided description of the WorkerPool. This field currently has a 512-character limit.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String
Returns Optional. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#expire_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. For a deleted resource, the time after which it will be permamently deleted.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#generation ⇒ ::Integer (readonly)
Returns Output only. A number that monotonically increases every time the user
modifies the desired state.
Please note that unlike v1, this is an int64 value. As with most Google
APIs, its JSON representation will be a string instead of an integer.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#instance_split_statuses ⇒ ::Array<::Google::Cloud::Run::V2::InstanceSplitStatus> (readonly)
Returns Output only. Detailed status information for corresponding instance splits.
See comments in reconciling for additional information on reconciliation
process in Cloud Run.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#instance_splits ⇒ ::Array<::Google::Cloud::Run::V2::InstanceSplit>
Returns Optional. Specifies how to distribute instances over a collection of
Revisions belonging to the WorkerPool. If instance split is empty or not
provided, defaults to 100% instances assigned to the latest Ready
Revision.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud.google.com/resource-manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/configuring/labels.
Cloud Run API v2 does not support labels with run.googleapis.com,
cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev
namespaces, and they will be rejected. All system labels in v1 now have a
corresponding field in v2 WorkerPool.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#last_modifier ⇒ ::String (readonly)
Returns Output only. Email address of the last authenticated modifier.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#latest_created_revision ⇒ ::String (readonly)
Returns Output only. Name of the last created revision. See comments in
reconciling for additional information on reconciliation process in Cloud
Run.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#latest_ready_revision ⇒ ::String (readonly)
Returns Output only. Name of the latest revision that is serving workloads. See
comments in reconciling for additional information on reconciliation
process in Cloud Run.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#launch_stage ⇒ ::Google::Api::LaunchStage
Returns Optional. The launch stage as defined by Google Cloud Platform
Launch Stages.
Cloud Run supports ALPHA, BETA, and GA. If no value is specified, GA
is assumed.
Set the launch stage to a preview stage on input to allow use of preview
features in that stage. On read (or output), describes whether the
resource uses preview features.
For example, if ALPHA is provided as input, but only BETA and GA-level features are used, this field will be BETA on output.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns The fully qualified name of this WorkerPool. In CreateWorkerPoolRequest, this field is ignored, and instead composed from CreateWorkerPoolRequest.parent and CreateWorkerPoolRequest.worker_id.
Format:
projects/{project}/locations/{location}/workerPools/{worker_id}.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#observed_generation ⇒ ::Integer (readonly)
Returns Output only. The generation of this WorkerPool currently serving workloads.
See comments in reconciling for additional information on reconciliation
process in Cloud Run. Please note that unlike v1, this is an int64 value.
As with most Google APIs, its JSON representation will be a string
instead of an integer.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#reconciling ⇒ ::Boolean (readonly)
Returns Output only. Returns true if the WorkerPool is currently being acted upon by the system to bring it into the desired state.
When a new WorkerPool is created, or an existing one is updated, Cloud Run
will asynchronously perform all necessary steps to bring the WorkerPool to
the desired serving state. This process is called reconciliation. While
reconciliation is in process, observed_generation,
latest_ready_revison, instance_split_statuses, and uri will have
transient values that might mismatch the intended state: Once
reconciliation is over (and this field is false), there are two possible
outcomes: reconciliation succeeded and the serving state matches the
WorkerPool, or there was an error, and reconciliation failed. This state
can be found in terminal_condition.state.
If reconciliation succeeded, the following fields will match:
instance_splits and instance_split_statuses, observed_generation and
generation, latest_ready_revision and latest_created_revision.
If reconciliation failed, instance_split_statuses, observed_generation,
and latest_ready_revision will have the state of the last serving
revision, or empty for newly created WorkerPools. Additional information on
the failure can be found in terminal_condition and conditions.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scaling ⇒ ::Google::Cloud::Run::V2::WorkerPoolScaling
Returns Optional. Specifies worker-pool-level scaling settings.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#template ⇒ ::Google::Cloud::Run::V2::WorkerPoolRevisionTemplate
Returns Required. The template used to create revisions for this WorkerPool.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#terminal_condition ⇒ ::Google::Cloud::Run::V2::Condition (readonly)
Returns Output only. The Condition of this WorkerPool, containing its readiness
status, and detailed error information in case it did not reach a serving
state. See comments in reconciling for additional information on
reconciliation process in Cloud Run.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#threat_detection_enabled ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether Cloud Run Threat Detection monitoring is enabled for the parent project of this worker pool.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. Server assigned unique identifier for the trigger. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last-modified time.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'proto_docs/google/cloud/run/v2/worker_pool.rb', line 327 class WorkerPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |