Class: Google::Cloud::Run::V2::SubmitBuildRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Run::V2::SubmitBuildRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/run/v2/build.rb
Overview
Request message for submitting a Build.
Defined Under Namespace
Classes: BuildpacksBuild, DockerBuild
Instance Attribute Summary collapse
-
#buildpack_build ⇒ ::Google::Cloud::Run::V2::SubmitBuildRequest::BuildpacksBuild
Build the source using Buildpacks.
-
#client ⇒ ::String
Optional.
-
#docker_build ⇒ ::Google::Cloud::Run::V2::SubmitBuildRequest::DockerBuild
Build the source using Docker.
-
#image_uri ⇒ ::String
Required.
-
#machine_type ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#release_track ⇒ ::Google::Api::LaunchStage
Optional.
-
#service_account ⇒ ::String
Optional.
-
#storage_source ⇒ ::Google::Cloud::Run::V2::StorageSource
Required.
-
#tags ⇒ ::Array<::String>
Optional.
-
#worker_pool ⇒ ::String
Optional.
Instance Attribute Details
#buildpack_build ⇒ ::Google::Cloud::Run::V2::SubmitBuildRequest::BuildpacksBuild
Returns Build the source using Buildpacks.
Note: The following fields are mutually exclusive: buildpack_build, docker_build. If a field in that set is populated, all other fields in the set will automatically be cleared.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#client ⇒ ::String
Returns Optional. The client that initiated the build request.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#docker_build ⇒ ::Google::Cloud::Run::V2::SubmitBuildRequest::DockerBuild
Returns Build the source using Docker. This means the source has a Dockerfile.
Note: The following fields are mutually exclusive: docker_build, buildpack_build. If a field in that set is populated, all other fields in the set will automatically be cleared.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#image_uri ⇒ ::String
Returns Required. Artifact Registry URI to store the built image.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#machine_type ⇒ ::String
Returns Optional. The machine type from default pool to use for the build. If left blank, cloudbuild will use a sensible default. Currently only E2_HIGHCPU_8 is supported. If worker_pool is set, this field will be ignored.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#parent ⇒ ::String
Returns Required. The project and location to build in. Location must be a region,
e.g., 'us-central1' or 'global' if the global builder is to be used.
Format:
projects/{project}/locations/{location}.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#release_track ⇒ ::Google::Api::LaunchStage
Returns Optional. The release track of the client that initiated the build request.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#service_account ⇒ ::String
Returns Optional. The service account to use for the build. If not set, the default Cloud Build service account for the project will be used.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#storage_source ⇒ ::Google::Cloud::Run::V2::StorageSource
Returns Required. Source for the build.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#tags ⇒ ::Array<::String>
Returns Optional. Additional tags to annotate the build.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#worker_pool ⇒ ::String
Returns Optional. Name of the Cloud Build Custom Worker Pool that should be used to
build the function. The format of this field is
projects/{project}/locations/{region}/workerPools/{workerPool} where
{project} and {region} are the project id and region respectively where
the worker pool is defined and {workerPool} is the short name of the
worker pool.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'proto_docs/google/cloud/run/v2/build.rb', line 73 class SubmitBuildRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Build the source using Docker. This means the source has a Dockerfile. class DockerBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Build the source using Buildpacks. # @!attribute [rw] runtime # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::String] # The runtime name, e.g. 'go113'. Leave blank for generic builds. # @!attribute [rw] function_target # @return [::String] # Optional. Name of the function target if the source is a function source. # Required for function builds. # @!attribute [rw] cache_image_uri # @return [::String] # Optional. cache_image_uri is the GCR/AR URL where the cache image will be # stored. cache_image_uri is optional and omitting it will disable caching. # This URL must be stable across builds. It is used to derive a # build-specific temporary URL by substituting the tag with the build ID. # The build will clean up the temporary image on a best-effort basis. # @!attribute [rw] base_image # @return [::String] # Optional. The base image to use for the build. # @!attribute [rw] environment_variables # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-provided build-time environment variables. # @!attribute [rw] enable_automatic_updates # @return [::Boolean] # Optional. Whether or not the application container will be enrolled in # automatic base image updates. When true, the application will be built on # a scratch base image, so the base layers can be appended at run time. # @!attribute [rw] project_descriptor # @return [::String] # Optional. project_descriptor stores the path to the project descriptor # file. When empty, it means that there is no project descriptor file in # the source. class BuildpacksBuild include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |